@@ -1,3 +1,9 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
                           cupsoptions.h  -  description
                              -------------------
@@ -25,13 +31,16 @@
 #include <qcombobox.h>
 #include <qptrlist.h>
 #include <qmap.h>
-#include "prefscontext.h"
+
+#include "scribusapi.h"
 
 /**
   *@author Franz Schmid
   */
 
-class CupsOptions : public QDialog
+class PrefsContext;
+
+class SCRIBUS_API CupsOptions : public QDialog
 {
     Q_OBJECT
 
