@@ -1,15 +1,12 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #ifndef NODEPALETTE_H
 #define NODEPALETTE_H
 
-#include <qdialog.h>
 #include <qbuttongroup.h>
 #include <qpushbutton.h>
 #include <qtoolbutton.h>
@@ -18,10 +15,16 @@
 #include <qtooltip.h>
 #include <qcheckbox.h>
 #include <qspinbox.h>
-#include "mspinbox.h"
-#include "scribusdoc.h"
+#include <qradiobutton.h>
 
-class NodePalette : public QDialog
+#include "scribusapi.h"
+#include "scrpalettebase.h"
+#include "mspinbox.h"
+
+class ScribusDoc;
+class ScribusView;
+
+class SCRIBUS_API NodePalette : public ScrPaletteBase
 {
 	Q_OBJECT
 
@@ -49,23 +52,29 @@ public:
 	QToolButton* RotateCCW;
 	QToolButton* RotateCW;
 	QToolButton* Expand;
-	QToolButton* Crop;
-	QCheckBox* AbsMode;
+	QToolButton* Shrink;
+	QToolButton* Enlarge;
+	QToolButton* Reduce;
+	QButtonGroup* AbsMode;
+	QRadioButton* absToCanvas;
+	QRadioButton* absToPage;
 	QCheckBox* EditCont;
 	QLabel* TextLabel1;
 	MSpinBox* YSpin;
 	QLabel* TextLabel2;
 	MSpinBox* XSpin;
 	QSpinBox *RotVal;
-	QSpinBox *ScaleVal;
+	QSpinBox *scalePercentage;
+	MSpinBox *scaleDistance;
 	QPushButton* ResetCont;
-	QPushButton* PushButton1;
-	void setDoc(ScribusDoc *dc);
+	QPushButton* editEditButton;
+	void setDoc(ScribusDoc *dc, ScribusView *vi);
+	ScribusDoc* currentDocument() const;
 	ScribusDoc *doc;
+	ScribusView *view;
 
 private slots:
 	void closeEvent(QCloseEvent *);
-	void EndEdit();
 	void MoveK();
 	void AddN();
 	void DelN();
@@ -81,8 +90,10 @@ private slots:
 	void MirrorV();
 	void doRotCCW();
 	void doRotCW();
-	void doCrop();
+	void doShrink();
 	void doExpand();
+	void doReduce();
+	void doEnlarge();
 	void ShearR();
 	void ShearL();
 	void ShearU();
@@ -96,14 +107,23 @@ public slots:
 	void HaveNode(bool have, bool mov);
 	void IsOpen();
 	void PolyStatus(int typ, uint size);
+	void languageChange();
+	void unitChange();
+	void EndEdit(); // allow remote closing
 
 protected:
+	void connectSignals();
+	void disconnectSignals();
 	QVBoxLayout* NodePaletteLayout;
+	QVBoxLayout* vboxLayout1;
 	QGridLayout* ButtonGroup1Layout;
 	QGridLayout* Layout2;
-
+	
+	double unitRatio;
+	
 signals:
 	void Schliessen();
+	void DocChanged();
 };
 
 #endif // NODEPALETTE_H
