@@ -1,29 +1,10 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-#include "oodrawimp.h"
-#include "oodrawimp.moc"
-#ifdef _MSC_VER
- #if (_MSC_VER >= 1200)
-  #include "win-config.h"
- #endif
-#else
- #include "config.h"
-#endif
-#include "customfdialog.h"
-#include "color.h"
-#include "scribusXml.h"
-#include "mpalette.h"
-#include "prefsfile.h"
-#include "prefscontext.h"
-#include "prefstable.h"
-#include "fileunzip.h"
-#include "serializer.h"
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
+#include <qwidget.h>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qregexp.h>
@@ -31,68 +12,197 @@
 #include <qdragobject.h>
 #include <qdir.h>
 #include <qstring.h>
+#include <qdom.h>
 #include <cmath>
 
+#include "oodrawimp.h"
+#include "oodrawimp.moc"
+
+#include "scconfig.h"
+
+#include "scribus.h"
+#include "scribusdoc.h"
+#include "pageitem.h"
+#include "fpointarray.h"
+#include "customfdialog.h"
+#include "commonstrings.h"
+#include "color.h"
+#include "scribusXml.h"
+#include "mpalette.h"
+#include "prefsmanager.h"
+#include "prefsfile.h"
+#include "prefscontext.h"
+#include "prefstable.h"
+#include "fileunzip.h"
+#include "selection.h"
+#include "serializer.h"
+#include "undomanager.h"
+#include "pluginmanager.h"
+#include "util.h"
+#include "scfontmetrics.h"
+#include "stylestack.h"
+#include "scraction.h"
+#include "menumanager.h"
+
 using namespace std;
 
-extern QPointArray FlattenPath(FPointArray ina, QValueList<uint> &Segs);
-extern bool loadText(QString nam, QString *Buffer);
-extern QPixmap loadIcon(QString nam);
-extern double RealCWidth(ScribusDoc *doc, QString name, QString ch, int Siz);
-extern FPoint GetMaxClipF(FPointArray Clip);
-extern PrefsFile* prefsFile;
-
-/*!
- \fn QString Name()
- \author Franz Schmid
- \date
- \brief Returns name of plugin
- \param None
- \retval QString containing name of plugin: Import SVG-Image...
- */
-QString Name()
+int oodrawimp_getPluginAPIVersion()
 {
-	return QObject::tr("Import &OpenOffice.org Draw...");
+	return PLUGIN_API_VERSION;
 }
 
-/*!
- \fn int Type()
- \author Franz Schmid
- \date
- \brief Returns type of plugin
- \param None
- \retval int containing type of plugin (1: Extra, 2: Import, 3: Export, 4: )
- */
-int Type()
+ScPlugin* oodrawimp_getPlugin()
 {
-	return 2;
+	OODrawImportPlugin* plug = new OODrawImportPlugin();
+	Q_CHECK_PTR(plug);
+	return plug;
 }
 
-int ID()
+void oodrawimp_freePlugin(ScPlugin* plugin)
 {
-	return 12;
+	OODrawImportPlugin* plug = dynamic_cast<OODrawImportPlugin*>(plugin);
+	Q_ASSERT(plug);
+	delete plug;
 }
 
-void Run(QWidget *d, ScribusApp *plug)
+OODrawImportPlugin::OODrawImportPlugin() :
+	LoadSavePlugin(),
+	importAction(new ScrAction(ScrAction::DLL, QIconSet(), "", QKeySequence(), this, "ImportOpenOfficeDraw"))
 {
-	QString fileName;
-	PrefsContext* prefs = prefsFile->getPluginContext("OODrawImport");
-	QString wdir = prefs->get("wdir", ".");
-	CustomFDialog diaf(d, wdir, QObject::tr("Open"), QObject::tr("OpenOffice.org Draw (*.sxd);;All Files (*)"));
-	if (diaf.exec())
+	// Set action info in languageChange, so we only have to do
+	// it in one place. This includes registering file formats.
+	languageChange();
+
+	// Then hook up the action
+	importAction->setEnabled(true);
+	connect( importAction, SIGNAL(activated()), SLOT(import()) );
+	ScMW->scrMenuMgr->addMenuItem(importAction, "FileImport");
+}
+
+OODrawImportPlugin::~OODrawImportPlugin()
+{
+	unregisterAll();
+	// note: importAction is automatically deleted by Qt
+};
+
+void OODrawImportPlugin::languageChange()
+{
+	importAction->setMenuText( tr("Import &OpenOffice.org Draw..."));
+	// (Re)register file formats
+	unregisterAll();
+	registerFormats();
+}
+
+const QString OODrawImportPlugin::fullTrName() const
+{
+	return QObject::tr("OpenOffice.org Draw Importer");
+}
+
+const ScActionPlugin::AboutData* OODrawImportPlugin::getAboutData() const
+{
+	AboutData* about = new AboutData;
+	about->authors = "Franz Schmid <franz@scribus.info>";
+	about->shortDescription = tr("Imports OpenOffice.org Draw Files");
+	about->description = tr("Imports most OpenOffice.org Draw files into the current document, converting their vector data into Scribus objects.");
+	about->license = "GPL";
+	Q_CHECK_PTR(about);
+	return about;
+}
+
+void OODrawImportPlugin::deleteAboutData(const AboutData* about) const
+{
+	Q_ASSERT(about);
+	delete about;
+}
+
+void OODrawImportPlugin::registerFormats()
+{
+	QString odtName = tr("OpenDocument 1.0 Draw", "Import/export format name");
+	FileFormat odtformat(this);
+	odtformat.trName = odtName; // Human readable name
+	odtformat.formatId = FORMATID_ODGIMPORT;
+	odtformat.filter = odtName + " (*.odg *.ODG)"; // QFileDialog filter
+	odtformat.nameMatch = QRegExp("\\.odg$", false);
+	odtformat.load = true;
+	odtformat.save = false;
+	odtformat.mimeTypes = QStringList("application/vnd.oasis.opendocument.graphics"); // MIME types
+	odtformat.priority = 64; // Priority
+	registerFormat(odtformat);
+
+	QString sxdName = tr("OpenOffice.org 1.x Draw", "Import/export format name");
+	FileFormat sxdformat(this);
+	sxdformat.trName = sxdName; // Human readable name
+	sxdformat.formatId = FORMATID_SXDIMPORT;
+	sxdformat.filter = sxdName + " (*.sxd *.SXD)"; // QFileDialog filter
+	sxdformat.nameMatch = QRegExp("\\.sxd$", false);
+	sxdformat.load = true;
+	sxdformat.save = false;
+	sxdformat.mimeTypes = QStringList("application/vnd.sun.xml.draw"); // MIME types
+	sxdformat.priority = 64; // Priority
+	registerFormat(sxdformat);
+}
+
+bool OODrawImportPlugin::fileSupported(QIODevice* /* file */) const
+{
+	// TODO: try to identify .sxd / .odt files
+	return true;
+}
+
+bool OODrawImportPlugin::loadFile(const QString & fileName, const FileFormat &, int flags, int /*index*/)
+{
+	// For this plugin, right now "load" and "import" are the same thing
+	return import(fileName, flags);
+}
+
+bool OODrawImportPlugin::import(QString fileName, int flags)
+{
+	if (!checkFlags(flags))
+		return false;
+	if (fileName.isEmpty())
 	{
-		fileName = diaf.selectedFile();
-		prefs->set("wdir", fileName.left(fileName.findRev("/")));
+		flags |= lfInteractive;
+		PrefsContext* prefs = PrefsManager::instance()->prefsFile->getPluginContext("OODrawImport");
+		QString wdir = prefs->get("wdir", ".");
+		CustomFDialog diaf(ScMW, wdir, QObject::tr("Open"), QObject::tr("OpenOffice.org Draw (*.sxd *.odg);;All Files (*)"));
+		if (diaf.exec())
+		{
+			fileName = diaf.selectedFile();
+			prefs->set("wdir", fileName.left(fileName.findRev("/")));
+		}
+		else
+			return true;
 	}
+	if (UndoManager::undoEnabled() && ScMW->HaveDoc)
+	{
+		UndoManager::instance()->beginTransaction(ScMW->doc->currentPage->getUName(),Um::IImageFrame,Um::ImportOOoDraw, fileName, Um::IImportOOoDraw);
+	}
+	else if (UndoManager::undoEnabled() && !ScMW->HaveDoc)
+		UndoManager::instance()->setUndoEnabled(false);
+	OODPlug dia;
+	bool importDone = dia.import(fileName, flags);
+	if (UndoManager::undoEnabled())
+		UndoManager::instance()->commit();
 	else
-		return;
-	OODPlug *dia = new OODPlug(plug, fileName);
-	delete dia;
+		UndoManager::instance()->setUndoEnabled(true);
+	if (dia.unsupported)
+		QMessageBox::warning(ScMW, CommonStrings::trWarning, tr("This file contains some unsupported features"), 1, 0, 0);
+	return importDone;
 }
 
-OODPlug::OODPlug( ScribusApp *plug, QString fileName )
+OODPlug::OODPlug()
 {
+	interactive = false;
+	unsupported = false;
+	Doku = NULL;
+}
+
+bool OODPlug::import( QString fileName, int flags )
+{
+	bool importDone = false;
+	interactive = (flags & LoadSavePlugin::lfInteractive);
 	QString f, f2, f3;
+	if ( !QFile::exists(fileName) )
+		return false;
 	m_styles.setAutoDelete( true );
 	FileUnzip* fun = new FileUnzip(fileName);
 	stylePath   = fun->getFile("styles.xml");
@@ -105,10 +215,10 @@ OODPlug::OODPlug( ScribusApp *plug, QString fileName )
 		docname = docname.left(docname.findRev("."));
 		loadText(stylePath, &f);
 		if(!inpStyles.setContent(f))
-			return;
+			return false;
 		loadText(contentPath, &f2);
 		if(!inpContents.setContent(f2))
-			return;
+			return false;
 		QFile f1(stylePath);
 		f1.remove();
 		QFile f2(contentPath);
@@ -135,17 +245,19 @@ OODPlug::OODPlug( ScribusApp *plug, QString fileName )
 		QFile f1(stylePath);
 		f1.remove();
 	}
-	Prog = plug;
 	QString CurDirP = QDir::currentDirPath();
 	QFileInfo efp(fileName);
 	QDir::setCurrent(efp.dirPath());
-	convert();
+	importDone = convert(flags);
 	QDir::setCurrent(CurDirP);
+	return importDone;
 }
 
-void OODPlug::convert()
+bool OODPlug::convert(int flags)
 {
 	bool ret = false;
+	bool isOODraw2 = false;
+	QDomNode drawPagePNode;
 	int PageCounter = 0;
 	createStyleMap( inpStyles );
 	QDomElement docElem = inpContents.documentElement();
@@ -154,44 +266,80 @@ void OODPlug::convert()
 		insertStyles( automaticStyles.toElement() );
 	QDomNode body = docElem.namedItem( "office:body" );
 	QDomNode drawPage = body.namedItem( "draw:page" );
+	if ( drawPage.isNull() )
+	{
+		QDomNode offDraw = body.namedItem( "office:drawing" );
+		drawPage = offDraw.namedItem( "draw:page" );
+		if (drawPage.isNull())
+		{
+			QMessageBox::warning( ScMW, CommonStrings::trWarning, tr("This document does not seem to be an OpenOffice Draw file.") );
+			return false;
+		}
+		else
+		{
+			isOODraw2 = true;
+			drawPagePNode = body.namedItem( "office:drawing" );
+		}
+	}
+	else 
+		drawPagePNode = body;
+	StyleStack::Mode mode = isOODraw2 ? StyleStack::OODraw2x : StyleStack::OODraw1x;
+	m_styleStack.setMode( mode );
 	QDomElement dp = drawPage.toElement();
 	QDomElement *master = m_styles[dp.attribute( "draw:master-page-name" )];
-	QDomElement *style = m_styles[master->attribute( "style:page-master-name" )];
-	QDomElement properties = style->namedItem( "style:properties" ).toElement();
+	QDomElement *style = NULL;
+	QDomElement properties;
+	if (isOODraw2)
+	{
+		style = m_styles[master->attribute( "style:page-layout-name" )];
+		properties = style->namedItem( "style:page-layout-properties" ).toElement();
+	}
+	else
+	{
+		style = m_styles[master->attribute( "style:page-master-name" )];
+		properties = style->namedItem( "style:properties" ).toElement();
+	}
 	double width = !properties.attribute( "fo:page-width" ).isEmpty() ? parseUnit(properties.attribute( "fo:page-width" ) ) : 550.0;
 	double height = !properties.attribute( "fo:page-height" ).isEmpty() ? parseUnit(properties.attribute( "fo:page-height" ) ) : 841.0;
-	if (!Prog->HaveDoc)
+	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
+		ScMW->doc->setPage(width, height, 0, 0, 0, 0, 0, 0, false, false);
+	else
 	{
-		Prog->doFileNew(width, height, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom");
-		ret = true;
+		if (!ScMW->HaveDoc || (flags & LoadSavePlugin::lfCreateDoc))
+		{
+			ScMW->doFileNew(width, height, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom");
+			ScMW->HaveNewDoc();
+			ret = true;
+		}
 	}
-	if (ret)
+	if ((ret) || (!interactive))
 	{
 		if (width > height)
-			Prog->doc->PageOri = 1;
+			ScMW->doc->PageOri = 1;
 		else
-			Prog->doc->PageOri = 0;
+			ScMW->doc->PageOri = 0;
+		ScMW->doc->PageSize = "Custom";
 		QDomNode mpg;
 		QDomElement metaElem = inpMeta.documentElement();
 		QDomElement mp = metaElem.namedItem( "office:meta" ).toElement();
 		mpg = mp.namedItem( "dc:title" );
 		if (!mpg.isNull())
-			Prog->doc->DocTitel = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setTitle(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "meta:initial-creator" );
 		if (!mpg.isNull())
-			Prog->doc->DocAutor = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setAuthor(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "dc:description" );
 		if (!mpg.isNull())
-			Prog->doc->DocComments = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setComments(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "dc:language" );
 		if (!mpg.isNull())
-			Prog->doc->DocLangInfo = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setLangInfo(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "meta:creation-date" );
 		if (!mpg.isNull())
-			Prog->doc->DocDate = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setDate(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "dc:creator" );
 		if (!mpg.isNull())
-			Prog->doc->DocContrib = QString::fromUtf8(mpg.toElement().text());
+			ScMW->doc->documentInfo.setContrib(QString::fromUtf8(mpg.toElement().text()));
 		mpg = mp.namedItem( "meta:keywords" );
 		if (!mpg.isNull())
 		{
@@ -201,47 +349,49 @@ void OODPlug::convert()
 				Keys += QString::fromUtf8(n.toElement().text())+", ";
 			}
 			if (Keys.length() > 2)
-				Prog->doc->DocKeyWords = Keys.left(Keys.length()-2);
+				ScMW->doc->documentInfo.setKeywords(Keys.left(Keys.length()-2));
 		}
 	}
-	Doku = Prog->doc;
-	Doku->ActPage->Deselect();
+	Doku = ScMW->doc;
+	FPoint minSize = Doku->minCanvasCoordinate;
+	FPoint maxSize = Doku->maxCanvasCoordinate;
+	ScMW->view->Deselect();
 	Elements.clear();
-	Doku->loading = true;
+	Doku->setLoading(true);
 	Doku->DoDrawing = false;
-	Doku->ActPage->setUpdatesEnabled(false);
-	Prog->ScriptRunning = true;
+	ScMW->view->setUpdatesEnabled(false);
+	ScMW->ScriptRunning = true;
 	qApp->setOverrideCursor(QCursor(Qt::waitCursor), true);
-	if (!Doku->PageColors.contains("Black"))
-		Doku->PageColors.insert("Black", CMYKColor(0, 0, 0, 255));
-	for( QDomNode drawPag = body.firstChild(); !drawPag.isNull(); drawPag = drawPag.nextSibling() )
+	Doku->PageColors.ensureBlackAndWhite();
+	for( QDomNode drawPag = drawPagePNode.firstChild(); !drawPag.isNull(); drawPag = drawPag.nextSibling() )
 	{
-		if ((ret) && (PageCounter > 0))
-			Prog->view->addPage(PageCounter);
 		QDomElement dpg = drawPag.toElement();
+		if (!interactive)
+		{
+			ScMW->doc->addPage(PageCounter);
+			ScMW->view->addPage(PageCounter);
+		}
+		PageCounter++;
 		m_styleStack.clear();
 		fillStyleStack( dpg );
 		parseGroup( dpg );
-		PageCounter++;
 	}
-	if (Elements.count() > 1)
+	Doku->m_Selection->clear();
+	if ((Elements.count() > 1) && (interactive))
 	{
-		Doku->ActPage->SelItem.clear();
 		for (uint a = 0; a < Elements.count(); ++a)
 		{
 			Elements.at(a)->Groups.push(Doku->GroupCounter);
-			if (!ret)
-				Doku->ActPage->SelItem.append(Elements.at(a));
 		}
 		Doku->GroupCounter++;
 	}
 	Doku->DoDrawing = true;
-	Doku->ActPage->setUpdatesEnabled(true);
-	Prog->ScriptRunning = false;
-	if (Prog->DLLinput == "")
-		Doku->loading = false;
+	ScMW->view->setUpdatesEnabled(true);
+	ScMW->ScriptRunning = false;
+	if (interactive)
+		Doku->setLoading(false);
 	qApp->setOverrideCursor(QCursor(Qt::arrowCursor), true);
-	if ((Elements.count() > 0) && (!ret))
+	if ((Elements.count() > 0) && (!ret) && (interactive))
 	{
 		Doku->DragP = true;
 		Doku->DraggedElem = 0;
@@ -249,13 +399,22 @@ void OODPlug::convert()
 		for (uint dre=0; dre<Elements.count(); ++dre)
 		{
 			Doku->DragElements.append(Elements.at(dre)->ItemNr);
+			Doku->m_Selection->addItem(Elements.at(dre));
 		}
 		ScriXmlDoc *ss = new ScriXmlDoc();
-		Doku->ActPage->setGroupRect();
-		QDragObject *dr = new QTextDrag(ss->WriteElem(&Doku->ActPage->SelItem, Doku), Doku->ActPage);
-		Doku->ActPage->DeleteItem();
+		ScMW->view->setGroupRect();
+		QDragObject *dr = new QTextDrag(ss->WriteElem(Doku, ScMW->view, Doku->m_Selection), ScMW->view->viewport());
+#ifndef QT_MAC
+// see #2196, #2526
+		Doku->itemSelection_DeleteItem();
+#endif
+		ScMW->view->resizeContents(qRound((maxSize.x() - minSize.x()) * ScMW->view->scale()), qRound((maxSize.y() - minSize.y()) * ScMW->view->scale()));
+		ScMW->view->scrollBy(qRound((Doku->minCanvasCoordinate.x() - minSize.x()) * ScMW->view->scale()), qRound((Doku->minCanvasCoordinate.y() - minSize.y()) * ScMW->view->scale()));
+		Doku->minCanvasCoordinate = minSize;
+		Doku->maxCanvasCoordinate = maxSize;
 		dr->setPixmap(loadIcon("DragPix.xpm"));
-		dr->drag();
+		if (!dr->drag())
+			qDebug("oodraw import: couldn't start drag operation!");
 		delete ss;
 		Doku->DragP = false;
 		Doku->DraggedElem = 0;
@@ -263,9 +422,10 @@ void OODPlug::convert()
 	}
 	else
 	{
-		Doku->setUnModified();
-		Prog->slotDocCh();
+		Doku->setModified(false);
+		ScMW->slotDocCh();
 	}
+	return true;
 }
 
 QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
@@ -274,10 +434,13 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 	FPointArray ImgClip;
 	ImgClip.resize(0);
 	VGradient gradient;
-	double GradientAngle;
+	double GradientAngle = 0;
+	double xGoff = 0;
+	double yGoff= 0;
 	bool HaveGradient = false;
 	int GradientType = 0;
-	double xGoff, yGoff;
+	double BaseX = Doku->currentPage->xOffset();
+	double BaseY = Doku->currentPage->yOffset();
 	double lwidth = 0;
 	double x, y, w, h;
 	double FillTrans = 0;
@@ -285,8 +448,8 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 	QValueList<double> dashes;
 	for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
-		QString StrokeColor = "None";
-		QString FillColor = "None";
+		QString StrokeColor = CommonStrings::None;
+		QString FillColor = CommonStrings::None;
 		FillTrans = 0;
 		StrokeTrans = 0;
 		int z = -1;
@@ -297,7 +460,7 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 		QString STag = b.tagName();
 		QString drawID = b.attribute("draw:name");
 		storeObjectStyles(b);
-		if( m_styleStack.hasAttribute("draw:stroke"))
+		if( m_styleStack.hasAttribute("draw:stroke") )
 		{
 			if( m_styleStack.attribute( "draw:stroke" ) == "none" )
 				lwidth = 0.0;
@@ -322,7 +485,7 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 						dashes << 14.4 << 14.4;
 					else if( style == "Fine Dotted")
 						dashes << 13 << 13;
-					else if( style == "Ultrafine 2 Dots 3 Dashes") 
+					else if( style == "Ultrafine 2 Dots 3 Dashes")
 						dashes << 1.45 << 3.6 << 1.45 << 3.6 << 7.2 << 3.6 << 7.2 << 3.6 << 7.2 << 3.6;
 					else if( style == "Line with Fine Dots")
 					{
@@ -418,12 +581,13 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 			w = parseUnit(b.attribute("svg:width"));
 			h = parseUnit(b.attribute("svg:height"));
 			double corner = parseUnit(b.attribute("draw:corner-radius"));
-			z = Doku->ActPage->PaintRect(x, y, w, h, lwidth, FillColor, StrokeColor);
-			PageItem* ite = Doku->ActPage->Items.at(z);
+			z = Doku->itemAdd(PageItem::Polygon, PageItem::Rectangle, BaseX+x, BaseY+y, w, h, lwidth, FillColor, StrokeColor, true);
+			PageItem* ite = Doku->Items->at(z);
 			if (corner != 0)
 			{
-				ite->RadRect = corner;
-				Doku->ActPage->SetFrameRound(ite);
+				ite->setCornerRadius(corner);
+				ite->SetFrameRound();
+				Doku->setRedrawBounding(ite);
 			}
 		}
 		else if( STag == "draw:circle" || STag == "draw:ellipse" )
@@ -432,7 +596,7 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 			y = parseUnit(b.attribute("svg:y")) ;
 			w = parseUnit(b.attribute("svg:width"));
 			h = parseUnit(b.attribute("svg:height"));
-			z = Doku->ActPage->PaintEllipse(x, y, w, h, lwidth, FillColor, StrokeColor);
+			z = Doku->itemAdd(PageItem::Polygon, PageItem::Ellipse, BaseX+x, BaseY+y, w, h, lwidth, FillColor, StrokeColor, true);
 		}
 		else if( STag == "draw:line" ) // line
 		{
@@ -440,73 +604,73 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 			double y1 = b.attribute( "svg:y1" ).isEmpty() ? 0.0 : parseUnit( b.attribute( "svg:y1" ) );
 			double x2 = b.attribute( "svg:x2" ).isEmpty() ? 0.0 : parseUnit( b.attribute( "svg:x2" ) );
 			double y2 = b.attribute( "svg:y2" ).isEmpty() ? 0.0 : parseUnit( b.attribute( "svg:y2" ) );
-			z = Doku->ActPage->PaintPoly(0, 0, 10, 10, lwidth, "None", StrokeColor);
-			PageItem* ite = Doku->ActPage->Items.at(z);
+			z = Doku->itemAdd(PageItem::PolyLine, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, CommonStrings::None, StrokeColor, true);
+			PageItem* ite = Doku->Items->at(z);
 			ite->PoLine.resize(4);
 			ite->PoLine.setPoint(0, FPoint(x1, y1));
 			ite->PoLine.setPoint(1, FPoint(x1, y1));
 			ite->PoLine.setPoint(2, FPoint(x2, y2));
 			ite->PoLine.setPoint(3, FPoint(x2, y2));
-			FPoint wh = GetMaxClipF(ite->PoLine);
-			ite->Width = wh.x();
-			ite->Height = wh.y();
+			FPoint wh = getMaxClipF(&ite->PoLine);
+			ite->setWidthHeight(wh.x(), wh.y());
 			ite->ClipEdited = true;
 			ite->FrameType = 3;
+			HaveGradient = false;
 			if (!b.hasAttribute("draw:transform"))
 			{
 				ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-				Doku->ActPage->AdjustItemSize(ite);
+				ScMW->view->AdjustItemSize(ite);
 			}
-		} 
+		}
 		else if ( STag == "draw:polygon" )
 		{
-			z = Doku->ActPage->PaintPoly(0, 0, 10, 10, lwidth, FillColor, StrokeColor);
-			PageItem* ite = Doku->ActPage->Items.at(z);
+			z = Doku->itemAdd(PageItem::Polygon, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, FillColor, StrokeColor, true);
+			PageItem* ite = Doku->Items->at(z);
 			ite->PoLine.resize(0);
-			appendPoints(&ite->PoLine, b);
-			FPoint wh = GetMaxClipF(ite->PoLine);
-			ite->Width = wh.x();
-			ite->Height = wh.y();
+			appendPoints(&ite->PoLine, b, true);
+			FPoint wh = getMaxClipF(&ite->PoLine);
+			ite->setWidthHeight(wh.x(), wh.y());
 			ite->ClipEdited = true;
 			ite->FrameType = 3;
 			if (!b.hasAttribute("draw:transform"))
 			{
 				ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-				Doku->ActPage->AdjustItemSize(ite);
+				ScMW->view->AdjustItemSize(ite);
 			}
 		}
 		else if( STag == "draw:polyline" )
 		{
-			z = Doku->ActPage->PaintPolyLine(0, 0, 10, 10, lwidth, "None", StrokeColor);
-			PageItem* ite = Doku->ActPage->Items.at(z);
+			z = Doku->itemAdd(PageItem::PolyLine, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, CommonStrings::None, StrokeColor, true);
+			PageItem* ite = Doku->Items->at(z);
 			ite->PoLine.resize(0);
-			appendPoints(&ite->PoLine, b);
-			FPoint wh = GetMaxClipF(ite->PoLine);
-			ite->Width = wh.x();
-			ite->Height = wh.y();
+			appendPoints(&ite->PoLine, b, false);
+			FPoint wh = getMaxClipF(&ite->PoLine);
+			ite->setWidthHeight(wh.x(), wh.y());
 			ite->ClipEdited = true;
 			ite->FrameType = 3;
 			if (!b.hasAttribute("draw:transform"))
 			{
 				ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-				Doku->ActPage->AdjustItemSize(ite);
+				ScMW->view->AdjustItemSize(ite);
 			}
 		}
 		else if( STag == "draw:path" )
 		{
-			z = Doku->ActPage->PaintPoly(0, 0, 10, 10, lwidth, FillColor, StrokeColor);
-			PageItem* ite = Doku->ActPage->Items.at(z);
+			FPointArray pArray;
+			PageItem::ItemType itype = parseSVG(b.attribute("svg:d"), &pArray) ? PageItem::PolyLine : PageItem::Polygon;
+			z = Doku->itemAdd(itype, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, FillColor, StrokeColor, true);
+			PageItem* ite = Doku->Items->at(z);
 			ite->PoLine.resize(0);
-			if (parseSVG( b.attribute( "svg:d" ), &ite->PoLine ))
-				ite->PType = 7;
+			ite->PoLine = pArray;
 			if (ite->PoLine.size() < 4)
 			{
-				Doku->ActPage->SelItem.append(ite);
-				Doku->ActPage->DeleteItem();
+				Doku->m_Selection->addItem(ite);
+				Doku->itemSelection_DeleteItem();
 				z = -1;
 			}
 			else
 			{
+				QWMatrix mat;
 				x = parseUnit(b.attribute("svg:x"));
 				y = parseUnit(b.attribute("svg:y")) ;
 				w = parseUnit(b.attribute("svg:width"));
@@ -516,19 +680,19 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 				double vw = 1;
 				double vh = 1;
 				parseViewBox(b, &vx, &vy, &vw, &vh);
-				QWMatrix mat;
+				double sx = (vw != 0.0) ? (w / vw) : w;
+				double sy = (vh != 0.0) ? (h / vh) : h;
 				mat.translate(x, y);
-				mat.scale(w / vw, h / vh);
+				mat.scale(sx, sy);
 				ite->PoLine.map(mat);
-				FPoint wh = GetMaxClipF(ite->PoLine);
-				ite->Width = wh.x();
-				ite->Height = wh.y();
+				FPoint wh = getMaxClipF(&ite->PoLine);
+				ite->setWidthHeight(wh.x(), wh.y());
 				ite->ClipEdited = true;
 				ite->FrameType = 3;
 				if (!b.hasAttribute("draw:transform"))
 				{
 					ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-					Doku->ActPage->AdjustItemSize(ite);
+					ScMW->view->AdjustItemSize(ite);
 				}
 			}
 		}
@@ -538,23 +702,28 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 			y = parseUnit(b.attribute("svg:y")) ;
 			w = parseUnit(b.attribute("svg:width"));
 			h = parseUnit(b.attribute("svg:height"));
-			z = Doku->ActPage->PaintText(x, y, w, h+(h*0.1), lwidth, StrokeColor);
+			z = Doku->itemAdd(PageItem::TextFrame, PageItem::Unspecified, BaseX+x, BaseY+y, w, h+(h*0.1), lwidth, CommonStrings::None, StrokeColor, true);
 		}
 		else
+		{
+			unsupported = true;
+			qDebug("Not supported yet: %s", STag.local8Bit().data());
 			continue;
+		}
 		if (z != -1)
 		{
-			PageItem* ite = Doku->ActPage->Items.at(z);
-			ite->Extra = 0;
-			ite->TExtra = 0;
-			ite->BExtra = 0;
-			ite->RExtra = 0;
+			PageItem* ite = Doku->Items->at(z);
+			ite->setTextToFrameDist(0.0, 0.0, 0.0, 0.0);
 			bool firstPa = false;
 			for ( QDomNode n = b.firstChild(); !n.isNull(); n = n.nextSibling() )
 			{
-				int FontSize = Doku->Dsize;
-				int AbsStyle = 0;
+				if ( !n.hasAttributes() && !n.hasChildNodes() )
+					continue;
 				QDomElement e = n.toElement();
+				if ( e.text().isEmpty() )
+					continue;
+				int FontSize = Doku->toolSettings.defSize;
+				int AbsStyle = 0;
 				if( m_styleStack.hasAttribute("fo:text-align"))
 				{
 					if (m_styleStack.attribute("fo:text-align") == "left")
@@ -564,119 +733,130 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 					if (m_styleStack.attribute("fo:text-align") == "right")
 						AbsStyle = 2;
 				}
-				if( m_styleStack.hasAttribute("fo:font-family"))
+				if( m_styleStack.hasAttribute("fo:font-size"))
 				{
-					FontSize = m_styleStack.attribute("fo:font-size").remove( "pt" ).toInt();
+					FontSize = (int) (m_styleStack.attribute("fo:font-size").remove( "pt" ).toFloat() * 10);
 				}
 /* ToDo: Add reading of Textstyles here */
+				ite->setLineSpacing((FontSize + FontSize * 0.2) / 10.0);
 				Serializer *ss = new Serializer("");
-				ite->LineSp = FontSize + FontSize * 0.2;
 				ss->Objekt = QString::fromUtf8(e.text())+QChar(10);
-				ss->GetText(ite, AbsStyle, Doku->Dfont, FontSize * 10, firstPa);
+				ss->GetText(ite, AbsStyle, Doku->toolSettings.defFont, FontSize, firstPa);
 				delete ss;
 				firstPa = true;
-				if (ite->PType != 7)
-					ite->PType = 4;
+				if (! ite->asPolyLine())
+					ite->convertTo(PageItem::TextFrame);
 			}
-			ite->Transparency = FillTrans;
-			ite->TranspStroke = StrokeTrans;
+			ite->setFillTransparency(FillTrans);
+			ite->setLineTransparency(StrokeTrans);
 			if (dashes.count() != 0)
 				ite->DashValues = dashes;
-			if (drawID != "")
-				ite->AnName = drawID;
+			if (!drawID.isEmpty())
+				ite->setItemName(drawID);
 			if (b.hasAttribute("draw:transform"))
 			{
 				parseTransform(&ite->PoLine, b.attribute("draw:transform"));
 				ite->ClipEdited = true;
 				ite->FrameType = 3;
-				FPoint wh = GetMaxClipF(ite->PoLine);
-				ite->Width = wh.x();
-				ite->Height = wh.y();
+				FPoint wh = getMaxClipF(&ite->PoLine);
+				ite->setWidthHeight(wh.x(), wh.y());
 				ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-				Doku->ActPage->AdjustItemSize(ite);
+				ScMW->view->AdjustItemSize(ite);
 			}
 			if (HaveGradient)
 			{
 				ite->GrType = 0;
-				ite->fill_gradient = gradient;
-				if (GradientType == 1)
+				if (gradient.Stops() > 1)
 				{
-					bool flipped = false;
-					if ((GradientAngle == 0) || (GradientAngle == 180) || (GradientAngle == 90) || (GradientAngle == 270))
+					ite->fill_gradient = gradient;
+					if (GradientType == 1)
 					{
-						if ((GradientAngle == 0) || (GradientAngle == 180))
+						bool flipped = false;
+						if ((GradientAngle == 0) || (GradientAngle == 180) || (GradientAngle == 90) || (GradientAngle == 270))
 						{
-							ite->GrType = 2;
-							Doku->ActPage->updateGradientVectors(ite);
-						}
-						else if ((GradientAngle == 90) || (GradientAngle == 270))
-						{
-							ite->GrType = 1;
-							Doku->ActPage->updateGradientVectors(ite);
-						}
-					}
-					else
-					{
-						if ((GradientAngle > 90) && (GradientAngle < 270))
-							GradientAngle -= 180;
-						else if ((GradientAngle > 270) && (GradientAngle < 360))
-						{
-							GradientAngle = 360 - GradientAngle;
-							flipped = true;
-						}
-						double xpos;
-						xpos = (ite->Width / 2) * tan(GradientAngle* 3.1415927 / 180.0) * (ite->Height / ite->Width) + (ite->Width / 2);
-						if ((xpos < 0) || (xpos > ite->Width))
-						{
-							xpos = (ite->Height / 2)- (ite->Height / 2) * tan(GradientAngle* 3.1415927 / 180.0) * (ite->Height / ite->Width);
-							if (flipped)
+							if ((GradientAngle == 0) || (GradientAngle == 180))
 							{
-								ite->GrEndX = ite->Width;
-								ite->GrEndY = ite->Height - xpos;
-								ite->GrStartX = 0;
-								ite->GrStartY = xpos;
+								ite->GrType = 2;
+								//ScMW->view->updateGradientVectors(ite);
+								ite->updateGradientVectors();
 							}
-							else
+							else if ((GradientAngle == 90) || (GradientAngle == 270))
 							{
-								ite->GrEndY = xpos;
-								ite->GrEndX = ite->Width;
-								ite->GrStartX = 0;
-								ite->GrStartY = ite->Height - xpos;
+								ite->GrType = 1;
+								//ScMW->view->updateGradientVectors(ite);
+								ite->updateGradientVectors();
 							}
 						}
 						else
 						{
-							ite->GrEndX = xpos;
-							ite->GrEndY = ite->Height;
-							ite->GrStartX = ite->Width - xpos;
-							ite->GrStartY = 0;
+							if ((GradientAngle > 90) && (GradientAngle < 270))
+								GradientAngle -= 180;
+							else if ((GradientAngle > 270) && (GradientAngle < 360))
+							{
+								GradientAngle = 360 - GradientAngle;
+								flipped = true;
+							}
+							double xpos;
+							xpos = (ite->width() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width()) + (ite->width() / 2);
+							if ((xpos < 0) || (xpos > ite->width()))
+							{
+								xpos = (ite->height() / 2)- (ite->height() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width());
+								if (flipped)
+								{
+									ite->GrEndX = ite->width();
+									ite->GrEndY = ite->height() - xpos;
+									ite->GrStartX = 0;
+									ite->GrStartY = xpos;
+								}
+								else
+								{
+									ite->GrEndY = xpos;
+									ite->GrEndX = ite->width();
+									ite->GrStartX = 0;
+									ite->GrStartY = ite->height() - xpos;
+								}
+							}
+							else
+							{
+								ite->GrEndX = xpos;
+								ite->GrEndY = ite->height();
+								ite->GrStartX = ite->width() - xpos;
+								ite->GrStartY = 0;
+							}
+							if (flipped)
+							{
+								ite->GrEndX = ite->width() - xpos;
+								ite->GrEndY = ite->height();
+								ite->GrStartX = xpos;
+								ite->GrStartY = 0;
+							}
+							ite->GrType = 6;
 						}
-						if (flipped)
+					}
+					if (GradientType == 2)
+					{
+						ite->GrType = 7;
+						ite->GrStartX = ite->width() * xGoff;
+						ite->GrStartY = ite->height()* yGoff;
+						if (ite->width() >= ite->height())
 						{
-							ite->GrEndX = ite->Width - xpos;
-							ite->GrEndY = ite->Height;
-							ite->GrStartX = xpos;
-							ite->GrStartY = 0;
+							ite->GrEndX = ite->width();
+							ite->GrEndY = ite->height() / 2.0;
 						}
-						ite->GrType = 6;
+						else
+						{
+							ite->GrEndX = ite->width() / 2.0;
+							ite->GrEndY = ite->height();
+						}
+						//ScMW->view->updateGradientVectors(ite);
+						ite->updateGradientVectors();
 					}
 				}
-				if (GradientType == 2)
+				else
 				{
-					ite->GrType = 7;
-					ite->GrStartX = ite->Width * xGoff;
-					ite->GrStartY = ite->Height* yGoff;
-					if (ite->Width >= ite->Height)
-					{
-						ite->GrEndX = ite->Width;
-						ite->GrEndY = ite->Height / 2.0;
-					}
-					else
-					{
-						ite->GrEndX = ite->Width / 2.0;
-						ite->GrEndY = ite->Height;
-					}
-					Doku->ActPage->updateGradientVectors(ite);
+					QPtrVector<VColorStop> cstops = gradient.colorStops();
+					ite->setFillColor(cstops.at(0)->name);
+					ite->setFillShade(cstops.at(0)->shade);
 				}
 				HaveGradient = false;
 			}
@@ -759,7 +939,7 @@ void OODPlug::storeObjectStyles( const QDomElement& object )
 double OODPlug::parseUnit(const QString &unit)
 {
 	QString unitval=unit;
-	if (unit == "")
+	if (unit.isEmpty())
 		return 0.0;
 	if( unit.right( 2 ) == "pt" )
 		unitval.replace( "pt", "" );
@@ -795,7 +975,7 @@ QColor OODPlug::parseColorN( const QString &rgbColor )
 QString OODPlug::parseColor( const QString &s )
 {
 	QColor c;
-	QString ret = "None";
+	QString ret = CommonStrings::None;
 	if( s.startsWith( "rgb(" ) )
 	{
 		QString parse = s.stripWhiteSpace();
@@ -828,11 +1008,15 @@ QString OODPlug::parseColor( const QString &s )
 		else
 			c = parseColorN( rgbColor );
 	}
-	CListe::Iterator it;
+	ColorList::Iterator it;
 	bool found = false;
+	int r, g, b;
+	QColor tmpR;
 	for (it = Doku->PageColors.begin(); it != Doku->PageColors.end(); ++it)
 	{
-		if (c == Doku->PageColors[it.key()].getRGBColor())
+		Doku->PageColors[it.key()].getRGB(&r, &g, &b);
+		tmpR.setRgb(r, g, b);
+		if (c == tmpR && Doku->PageColors[it.key()].getColorModel() == colorModelRGB)
 		{
 			ret = it.key();
 			found = true;
@@ -840,10 +1024,12 @@ QString OODPlug::parseColor( const QString &s )
 	}
 	if (!found)
 	{
-		CMYKColor tmp;
+		ScColor tmp;
 		tmp.fromQColor(c);
+		tmp.setSpotColor(false);
+		tmp.setRegistrationColor(false);
 		Doku->PageColors.insert("FromOODraw"+c.name(), tmp);
-		Prog->Mpal->Cpal->SetColors(Doku->PageColors);
+		ScMW->propertiesPalette->updateColorList();
 		ret = "FromOODraw"+c.name();
 	}
 	return ret;
@@ -868,7 +1054,7 @@ void OODPlug::parseTransform(FPointArray *composite, const QString &transform)
 		if(subtransform[0] == "rotate")
 		{
 			result = QWMatrix();
-			result.rotate(-parseUnit(params[0]) * 180 / 3.1415927);
+			result.rotate(-parseUnit(params[0]) * 180 / M_PI);
 			composite->map(result);
 		}
 		else if(subtransform[0] == "translate")
@@ -890,13 +1076,13 @@ void OODPlug::parseTransform(FPointArray *composite, const QString &transform)
 		else if(subtransform[0] == "skewx")
 		{
 			result = QWMatrix();
-			result.shear(-params[0].toDouble(), 0.0);
+			result.shear(-tan(params[0].toDouble()), 0.0);
 			composite->map(result);
 		}
 		else if(subtransform[0] == "skewy")
 		{
 			result = QWMatrix();
-			result.shear(0.0, -params[0].toDouble());
+			result.shear(0.0, -tan(params[0].toDouble()));
 			composite->map(result);
 		}
 	}
@@ -915,7 +1101,7 @@ void OODPlug::parseViewBox( const QDomElement& object, double *x, double *y, dou
 	}
 }
 
-void OODPlug::appendPoints(FPointArray *composite, const QDomElement& object)
+void OODPlug::appendPoints(FPointArray *composite, const QDomElement& object, bool closePath)
 {
 	double x = parseUnit(object.attribute("svg:x"));
 	double y = parseUnit(object.attribute("svg:y")) ;
@@ -926,6 +1112,8 @@ void OODPlug::appendPoints(FPointArray *composite, const QDomElement& object)
 	double vw = 1;
 	double vh = 1;
 	parseViewBox(object, &vx, &vy, &vw, &vh);
+	double sx = (vw != 0.0) ? (w / vw) : w;
+	double sy = (vh != 0.0) ? (h / vh) : h;
 	QStringList ptList = QStringList::split( ' ', object.attribute( "draw:points" ) );
 	FPoint point, firstP;
 	bool bFirst = true;
@@ -947,11 +1135,14 @@ void OODPlug::appendPoints(FPointArray *composite, const QDomElement& object)
 			composite->addPoint(point);
 		}
     }
-	composite->addPoint(firstP);
-	composite->addPoint(firstP);
+	if (closePath)
+	{
+		composite->addPoint(firstP);
+		composite->addPoint(firstP);
+	}
 	QWMatrix mat;
 	mat.translate(x, y);
-	mat.scale(w / vw, h / vh);
+	mat.scale(sx, sy);
 	composite->map(mat);
 }
 
