@@ -1,13 +1,11 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
- *   Riku Leino, riku.leino@gmail.com                                          *
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
+ *   Riku Leino, tsoots@gmail.com                                          *
  ***************************************************************************/
 #include "nfttemplate.h"
 #include <qfileinfo.h>
@@ -30,6 +28,7 @@ void nfttemplate::remove()
 		bool collect = false;
 		tmplXml->open(IO_ReadOnly);
 		QTextStream stream(tmplXml);
+		stream.setEncoding(QTextStream::UnicodeUTF8);
 		QString line = stream.readLine();
 		while (line != NULL)
 		{
