@@ -1,11 +1,9 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #ifndef CMDCOLOR_H
 #define CMDCOLOR_H
 
@@ -43,7 +41,7 @@ PyDoc_STRVAR(scribus_getcolorasrgb__doc__,
 QT_TR_NOOP("getColorAsRGB(\"name\") -> tuple\n\
 \n\
 Returns a tuple (R,G,B) containing the three color components of the\n\
-color \"name\" from the current document, converted to the RGB colour\n\
+color \"name\" from the current document, converted to the RGB color\n\
 space. If no document is open, returns the value of the named color\n\
 from the default document colors.\n\
 \n\
@@ -72,7 +70,7 @@ PyDoc_STRVAR(scribus_newcolor__doc__,
 QT_TR_NOOP("defineColor(\"name\", c, m, y, k)\n\
 \n\
 Defines a new color \"name\". The color Value is defined via four components:\n\
-c = Cyan, m = Magenta, y = Yellow and k = Black. Color components should be in\n\
+c = Cyan, m = Magenta, y = Yello and k = Black. Color components should be in\n\
 the range from 0 to 255.\n\
 \n\
 May raise ValueError if an invalid color name is specified.\n\
