@@ -1,15 +1,15 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 #include "cmdmani.h"
 #include "cmdutil.h"
+#include "mpalette.h" //CB argh.. noooooooooooooooooooooooooooooooooooo FIXME see other FIXME
+#include "selection.h"
 
-PyObject *scribus_loadimage(PyObject */*self*/, PyObject* args)
+PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	char *Image;
@@ -20,17 +20,17 @@ PyObject *scribus_loadimage(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == NULL)
 		return NULL;
-	if (item->PType != FRAME_IMAGE)
+	if (!item->asImageFrame())
 	{
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error"));
 		return NULL;
 	}
-	item->OwnPage->LoadPict(QString::fromUtf8(Image), item->ItemNr);
+	ScMW->doc->LoadPict(QString::fromUtf8(Image), item->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_scaleimage(PyObject */*self*/, PyObject* args)
+PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -41,20 +41,19 @@ PyObject *scribus_scaleimage(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == NULL)
 		return NULL;
-	if (!item->PType == FRAME_IMAGE)
+	if (! item->asImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error"));
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error"));
 		return NULL;
 	}
-	item->LocalScX = x;
-	item->LocalScY = y;
-	item->OwnPage->ChLocalSc(x, y);
-	item->OwnPage->UpdatePic();
+	item->setImageXYScale(x, y);
+	ScMW->doc->itemSelection_SetImageScale(x, y); //CB why when this is done above?
+	ScMW->doc->updatePic();
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_moveobjrel(PyObject */*self*/, PyObject* args)
+PyObject *scribus_moveobjrel(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -63,30 +62,35 @@ PyObject *scribus_moveobjrel(PyObject */*self*/, PyObject* args)
 	if(!checkHaveDocument())
 		return NULL;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
-	if (item == NULL)
+	if (item==NULL)
 		return NULL;
 	// Grab the old selection
-	QPtrList<PageItem> oldSelection = item->OwnPage->SelItem;
+	//QPtrList<PageItem> oldSelection = ScMW->view->SelItem;
+	//int tempList=ScMW->doc->selection->backupToTempList(0);
+	Selection tempSelection(*ScMW->doc->m_Selection);
+	ScMW->doc->m_Selection->clear();
 	// Clear the selection
-	item->OwnPage->Deselect();
+	ScMW->view->Deselect();
 	// Select the item, which will also select its group if
 	// there is one.
-	item->OwnPage->SelectItemNr(item->ItemNr);
+	ScMW->view->SelectItemNr(item->ItemNr);
 	// Move the item, or items
-	if (item->OwnPage->SelItem.count() > 1)
-		item->OwnPage->moveGroup(ValueToPoint(x), ValueToPoint(y));
+	if (ScMW->doc->m_Selection->count() > 1)
+		ScMW->view->moveGroup(ValueToPoint(x), ValueToPoint(y));
 	else
-		item->OwnPage->MoveItem(ValueToPoint(x), ValueToPoint(y), item);
+		ScMW->view->MoveItem(ValueToPoint(x), ValueToPoint(y), item);
 	// Now restore the selection. We just have to go through and select
 	// each and every item, unfortunately.
-	item->OwnPage->Deselect();
-	for ( oldSelection.first(); oldSelection.current(); oldSelection.next() )
-		item->OwnPage->SelectItemNr(oldSelection.current()->ItemNr);
+	//ScMW->doc->selection->restoreFromTempList(0, tempList);
+	*ScMW->doc->m_Selection=tempSelection;
+	//ScMW->view->Deselect();
+	//for ( oldSelection.first(); oldSelection.current(); oldSelection.next() )
+	//	ScMW->view->SelectItemNr(oldSelection.current()->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_moveobjabs(PyObject */*self*/, PyObject* args)
+PyObject *scribus_moveobjabs(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -98,31 +102,35 @@ PyObject *scribus_moveobjabs(PyObject */*self*/, PyObject* args)
 	if (item == NULL)
 		return NULL;
 	// Grab the old selection
-	QPtrList<PageItem> oldSelection = item->OwnPage->SelItem;
+	//QPtrList<PageItem> oldSelection = ScMW->view->SelItem;
+	//int tempList=ScMW->doc->selection->backupToTempList(0);
+	Selection tempSelection(*ScMW->doc->m_Selection);
 	// Clear the selection
-	item->OwnPage->Deselect();
+	ScMW->view->Deselect();
 	// Select the item, which will also select its group if
 	// there is one.
-	item->OwnPage->SelectItemNr(item->ItemNr);
+	ScMW->view->SelectItemNr(item->ItemNr);
 	// Move the item, or items
-	if (item->OwnPage->SelItem.count() > 1)
+	if (ScMW->doc->m_Selection->count() > 1)
 	{
 		double x2, y2, w, h;
-		item->OwnPage->getGroupRect(&x2, &y2, &w, &h);
-		item->OwnPage->moveGroup(ValueToPoint(x) - x2, ValueToPoint(y) - y2);
+		ScMW->view->getGroupRect(&x2, &y2, &w, &h);
+		ScMW->view->moveGroup(pageUnitXToDocX(x) - x2, pageUnitYToDocY(y) - y2);
 	}
 	else
-		item->OwnPage->MoveItem(ValueToPoint(x) - item->Xpos, ValueToPoint(y) - item->Ypos, item);
+		ScMW->view->MoveItem(pageUnitXToDocX(x) - item->xPos(), pageUnitYToDocY(y) - item->yPos(), item);
 	// Now restore the selection. We just have to go through and select
 	// each and every item, unfortunately.
-	item->OwnPage->Deselect();
-	for ( oldSelection.first(); oldSelection.current(); oldSelection.next() )
-		item->OwnPage->SelectItemNr(oldSelection.current()->ItemNr);
+	//ScMW->doc->selection->restoreFromTempList(0, tempList);
+	*ScMW->doc->m_Selection=tempSelection;
+	//ScMW->view->Deselect();
+	//for ( oldSelection.first(); oldSelection.current(); oldSelection.next() )
+//		ScMW->view->SelectItemNr(oldSelection.current()->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_rotobjrel(PyObject */*self*/, PyObject* args)
+PyObject *scribus_rotobjrel(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x;
@@ -133,12 +141,12 @@ PyObject *scribus_rotobjrel(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == NULL)
 		return NULL;
-	item->OwnPage->RotateItem(item->Rot - x, item->ItemNr);
+	ScMW->view->RotateItem(item->rotation() - x, item->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_rotobjabs(PyObject */*self*/, PyObject* args)
+PyObject *scribus_rotobjabs(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x;
@@ -149,12 +157,12 @@ PyObject *scribus_rotobjabs(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == NULL)
 		return NULL;
-	item->OwnPage->RotateItem(x * -1.0, item->ItemNr);
+	ScMW->view->RotateItem(x * -1.0, item->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_sizeobjabs(PyObject */*self*/, PyObject* args)
+PyObject *scribus_sizeobjabs(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double x, y;
@@ -165,12 +173,12 @@ PyObject *scribus_sizeobjabs(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
 	if (item == NULL)
 		return NULL;
-	item->OwnPage->SizeItem(ValueToPoint(x) - item->Xpos, ValueToPoint(y) - item->Ypos, item->ItemNr);
+	ScMW->view->SizeItem(ValueToPoint(x), ValueToPoint(y), item->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_groupobj(PyObject */*self*/, PyObject* args)
+PyObject *scribus_groupobj(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	PyObject *il = 0;
@@ -178,16 +186,19 @@ PyObject *scribus_groupobj(PyObject */*self*/, PyObject* args)
 		return NULL;
 	if(!checkHaveDocument())
 		return NULL;
-	Page *p = Carrier->doc->ActPage;
-	uint ap = Carrier->doc->ActPage->PageNr;
+	uint ap = ScMW->doc->currentPage->pageNr();
+	// If we were passed a list of items to group...
 	if (il != 0)
 	{
 		int len = PyList_Size(il);
-		if (len == 0)
+		if (len < 2)
 		{
-			Py_INCREF(Py_None);
-			return Py_None;
+			// We can't very well group only one item
+			PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error"));
+			return NULL;
 		}
+		QStringList oldSelection = getSelectedItemsByName();
+		ScMW->view->Deselect();
 		for (int i = 0; i < len; i++)
 		{
 			// FIXME: We might need to explicitly get this string as utf8
@@ -197,22 +208,33 @@ PyObject *scribus_groupobj(PyObject */*self*/, PyObject* args)
 			PageItem *ic = GetUniqueItem(QString::fromUtf8(Name));
 			if (ic == NULL)
 				return NULL;
-			ic->OwnPage->SelectItemNr(ic->ItemNr);
-			p = ic->OwnPage;
+			ScMW->view->SelectItemNr(ic->ItemNr);
 		}
+		ScMW->GroupObj();
+		setSelectedItemsByName(oldSelection);
 	}
-	if (p->SelItem.count() != 0)
+	// or if no argument list was given but there is a selection...
+	else if (ScMW->doc->m_Selection->count() != 0)
 	{
-		Carrier->view->GotoPage(p->PageNr);
-		Carrier->GroupObj();
-		p->Deselect();
-		Carrier->view->GotoPage(ap);
+		if (ScMW->doc->m_Selection->count() < 2)
+		{
+			// We can't very well group only one item
+			PyErr_SetString(NoValidObjectError, QObject::tr("Can't group less than two items", "python error"));
+			return NULL;
+		}
+		ScMW->GroupObj();
+		ScMW->view->GotoPage(ap);
+	}
+	else
+	{
+		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error"));
+		return NULL;
 	}
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_ungroupobj(PyObject */*self*/, PyObject* args)
+PyObject *scribus_ungroupobj(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &Name))
@@ -222,15 +244,12 @@ PyObject *scribus_ungroupobj(PyObject */*self*/, PyObject* args)
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
 	if (i == NULL)
 		return NULL;
-	uint p = Carrier->doc->ActPage->PageNr;
-	Carrier->view->GotoPage(i->OwnPage->PageNr);
-	Carrier->UnGroupObj();
-	Carrier->view->GotoPage(p);
+	ScMW->UnGroupObj();
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_scalegroup(PyObject */*self*/, PyObject* args)
+PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	double sc;
@@ -246,38 +265,38 @@ PyObject *scribus_scalegroup(PyObject */*self*/, PyObject* args)
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
 	if (i == NULL)
 		return NULL;
-	i->OwnPage->Deselect();
-	i->OwnPage->SelectItemNr(i->ItemNr);
-	int h = i->OwnPage->HowTo;
-	i->OwnPage->HowTo = 1;
-	i->OwnPage->scaleGroup(sc, sc);
-	i->OwnPage->HowTo = h;
+	ScMW->view->Deselect();
+	ScMW->view->SelectItemNr(i->ItemNr);
+	int h = ScMW->view->frameResizeHandle;
+	ScMW->view->frameResizeHandle = 1;
+	ScMW->view->scaleGroup(sc, sc);
+	ScMW->view->frameResizeHandle = h;
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_getselobjnam(PyObject */*self*/, PyObject* args)
+PyObject *scribus_getselobjnam(PyObject* /* self */, PyObject* args)
 {
 	int i = 0;
 	if (!PyArg_ParseTuple(args, "|i", &i))
 		return NULL;
 	if(!checkHaveDocument())
 		return NULL;
-	if ((i < static_cast<int>(Carrier->doc->ActPage->SelItem.count())) && (i > -1))
-		return PyString_FromString(Carrier->doc->ActPage->SelItem.at(i)->AnName);
+	if ((i < static_cast<int>(ScMW->doc->m_Selection->count())) && (i > -1))
+		return PyString_FromString(ScMW->doc->m_Selection->itemAt(i)->itemName().utf8());
 	else
 		// FIXME: Should probably return None if no selection?
 		return PyString_FromString("");
 }
 
-PyObject *scribus_selcount(PyObject */*self*/)
+PyObject *scribus_selcount(PyObject* /* self */)
 {
 	if(!checkHaveDocument())
 		return NULL;
-	return PyInt_FromLong(static_cast<long>(Carrier->doc->ActPage->SelItem.count()));
+	return PyInt_FromLong(static_cast<long>(ScMW->doc->m_Selection->count()));
 }
 
-PyObject *scribus_selectobj(PyObject */*self*/, PyObject* args)
+PyObject *scribus_selectobj(PyObject* /* self */, PyObject* args)
 {
 	char *Name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "es", "utf-8", &Name))
@@ -287,22 +306,21 @@ PyObject *scribus_selectobj(PyObject */*self*/, PyObject* args)
 	PageItem *i = GetUniqueItem(QString::fromUtf8(Name));
 	if (i == NULL)
 		return NULL;
-	i->OwnPage->SelectItemNr(i->ItemNr);
+	ScMW->view->SelectItemNr(i->ItemNr);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_deselect(PyObject */*self*/)
+PyObject *scribus_deselect(PyObject* /* self */)
 {
 	if(!checkHaveDocument())
 		return NULL;
-	for (uint i = 0; i < Carrier->view->Pages.count(); i++)
-		Carrier->view->Pages.at(i)->Deselect();
+	ScMW->view->Deselect();
 	Py_INCREF(Py_None);
 	return Py_None;
 }
 
-PyObject *scribus_lockobject(PyObject */*self*/, PyObject* args)
+PyObject *scribus_lockobject(PyObject* /* self */, PyObject* args)
 {
 	char *name = const_cast<char*>("");
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
@@ -312,30 +330,30 @@ PyObject *scribus_lockobject(PyObject */*self*/, PyObject* args)
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == NULL)
 		return NULL;
+	item->toggleLock();
+	if (item->locked())
+		return PyInt_FromLong(1);
+	return PyInt_FromLong(0);
+}
+
+PyObject *scribus_islocked(PyObject* /* self */, PyObject* args)
+{
+	char *name = const_cast<char*>("");
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
+		return NULL;
 	// FIXME: Rather than toggling the lock, we should probably let the user set the lock state
 	// and instead provide a different function like toggleLock()
-	item->Locked = !item->Locked;
-	if (item->Locked)
-		return PyBool_FromLong(1);
-	return PyBool_FromLong(0);
-}
-
-PyObject *scribus_islocked(PyObject */*self*/, PyObject* args)
-{
-	char *name = const_cast<char*>("");
-	if (!PyArg_ParseTuple(args, "|es", "utf-8", &name))
-		return NULL;
 	if(!checkHaveDocument())
 		return NULL;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == NULL)
 		return NULL;
-	if (item->Locked)
+	if (item->locked())
 		return PyBool_FromLong(1);
 	return PyBool_FromLong(0);
 }
 
-PyObject *scribus_setscaleimagetoframe(PyObject */*self*/, PyObject* args, PyObject* kw)
+PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyObject* kw)
 {
 	char *name = const_cast<char*>("");
 	long int scaleToFrame = 0;
@@ -348,7 +366,7 @@ PyObject *scribus_setscaleimagetoframe(PyObject */*self*/, PyObject* args, PyObj
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == NULL)
 		return NULL;
-	if (item->PType != FRAME_IMAGE)
+	if (! item->asImageFrame())
 	{
 		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error"));
 		return NULL;
@@ -361,9 +379,13 @@ PyObject *scribus_setscaleimagetoframe(PyObject */*self*/, PyObject* args, PyObj
 	if (proportional != -1)
 		item->AspectRatio = proportional > 0;
 	// Force the braindead app to notice the changes
-	item->OwnPage->AdjustPictScale(item);
-	item->OwnPage->AdjustPreview(item, false);
-	item->OwnPage->RefreshItem(item);
+	
+	//FIXME emit or something so we dont need this
+	ScMW->propertiesPalette->setLvalue(item->imageXScale(), item->imageYScale(), item->imageXOffset(), item->imageYOffset());
+	item->AdjustPictScale();
+	//ScMW->view->AdjustPictScale(item);
+	
+	ScMW->view->RefreshItem(item);
 	Py_INCREF(Py_None);
 	return Py_None;
 }
