@@ -708,7 +708,7 @@ void PSLib::PS_ImageData(PageItem *c, QString fn, QString Name, QString Prof, bo
 	image.imgInfo.layerInfo.clear();
 	image.imgInfo.RequestProps = c->pixm.imgInfo.RequestProps;
 	image.imgInfo.isRequest = c->pixm.imgInfo.isRequest;
-	image.LoadPicture(fn, Prof, 0, UseEmbedded, UseProf, 0, 300, &dummy);
+	image.LoadPicture(fn, Prof, 0, UseEmbedded, UseProf, ScImage::CMYKData, 300, &dummy);
 	image.applyEffect(c->effectsInUse, colorsToUse, true);
 	ImgStr = image.ImageToCMYK_PS(-1, true);
 	if (CompAvail)
@@ -785,7 +785,7 @@ void PSLib::PS_image(PageItem *c, double x, double y, QString fn, double scalex,
 		image.imgInfo.layerInfo.clear();
 		image.imgInfo.RequestProps = c->pixm.imgInfo.RequestProps;
 		image.imgInfo.isRequest = c->pixm.imgInfo.isRequest;
-		image.LoadPicture(fn, Prof, 0, UseEmbedded, UseProf, 0, 300, &dummy);
+		image.LoadPicture(fn, Prof, 0, UseEmbedded, UseProf, ScImage::CMYKData, 300, &dummy);
 		image.applyEffect(c->effectsInUse, colorsToUse, true);
 		int w = image.width();
 		int h = image.height();
@@ -2462,7 +2462,7 @@ void PSLib::setTextCh(ScribusDoc* Doc, PageItem* ite, bool gcr, uint a, uint d,
 			QString out2;
 			//CB Section numbering
 			//out2 = out.arg(a+Doc->FirstPnum, -zae);
-			out2=out.arg(Doc->getSectionPageNumberForPageIndex(a), -zae);
+			out2=out.arg(Doc->getSectionPageNumberForPageIndex(a), -(int) zae);
 			chx = out2.mid(d-za2, 1);
 		}
 	}
