@@ -1,3 +1,9 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
                           serializer.h  -  description
                              -------------------
@@ -19,12 +25,13 @@
 #define SERIALIZER_H
 
 #include <qstring.h>
+#include "scribusapi.h"
 #include "scribusview.h"
 /**
   *@author Franz Schmid
   */
 
-class Serializer {
+class SCRIBUS_API Serializer {
 public: 
 	Serializer(QString name);
 	~Serializer() {};
